import 'package:http/http.dart';
import 'model/crack.dart';
import 'model/game.dart';
import 'dart:convert';

class CrackWatch {
  final String _baseUrl = 'api.crackwatch.com';
  Client _client;

  CrackWatch() {
    _client = Client();
  }

  Future<List<Game>> getGames(
      {int page, String sortBy, bool isSortInverted, bool isAAA, bool isReleased, bool isCracked}) async {
    var url = _buildUrl('games',
        page: page,
        sortBy: sortBy,
        isSortInverted: isSortInverted,
        isAAA: isAAA,
        isReleased: isReleased,
        isCracked: isCracked);
    var response = await _client.get(url);

    if (response.statusCode == 200) {
      var body = json.decode(response.body);
      var games = <Game>[];

      for (var game in body) {
        games.add(Game.fromJson(game));
      }

      return games;
    } else {
      throw Exception('Status code ${response.statusCode}');
    }
  }

  Future<List<Crack>> getCracks({int page = 0}) async {
    var url = _buildUrl('cracks', page: page);
    var response = await _client.get(url);

    if (response.statusCode == 200) {
      var body = json.decode(response.body);
      var cracks = <Crack>[];

      for (var crack in body) {
        cracks.add(Crack.fromJson(crack));
      }

      return cracks;
    } else {
      throw Exception('Status code ${response.statusCode}');
    }
  }

  Uri _buildUrl(String path,
      {int page, String sortBy, bool isSortInverted, bool isAAA, bool isReleased, bool isCracked}) {
    var parameters = {
      if (page != null) 'page': '$page',
      if (sortBy != null) 'sort_by': sortBy,
      if (isSortInverted != null) 'is_sort_inverted': '$isSortInverted',
      if (isAAA != null) 'is_aaa': '$isAAA',
      if (isReleased != null) 'is_released': '$isReleased',
      if (isCracked != null) 'is_cracked': '$isCracked',
    };

    var url = Uri.https(_baseUrl, 'api/$path', parameters);
    return url;
  }
}
