import 'package:crackwatch/crackwatch.dart';
import 'package:crackwatch/src/enum/sort_by.dart';
import 'package:test/test.dart';

void main() {
  CrackWatch cw;

  group('getGames', () {
    setUp(() async {
      cw = CrackWatch();
      await Future.delayed(const Duration(seconds: 2));
    });

    tearDown(() {
      cw = null;
    });

    test('without any arguments', () async {
      var games = await cw.getGames();

      expect(games.length, equals(30));
    });

    test('with page number', () async {
      var games = await cw.getGames(page: 1);
      expect(games.length, equals(30));
    });

    test('with sort by release_date', () async {
      var games = await cw.getGames(sortBy: SortBy.releaseDate);
      expect(games.length, equals(30));
    });

    test('with sort by crack_date', () async {
      var games = await cw.getGames(sortBy: SortBy.crackDate);
      expect(games.length, equals(30));
    });

    test('with is_sort_inverted TRUE', () async {
      var games = await cw.getGames(isSortInverted: true);
      expect(games.length, equals(30));
    });

    test('with is_sort_inverted FALSE', () async {
      var games = await cw.getGames(isSortInverted: true);
      expect(games.length, equals(30));
    });

    test('with is_sort_inverted FALSE', () async {
      var games = await cw.getGames(isSortInverted: false);
      expect(games.length, equals(30));
    });

    test('with is_aaa TRUE', () async {
      var games = await cw.getGames(isAAA: true);
      expect(games.length, equals(30));
    });

    test('with is_aaa FALSE', () async {
      var games = await cw.getGames(isAAA: false);
      expect(games.length, equals(30));
    });

    test('with is_released TRUE', () async {
      var games = await cw.getGames(isReleased: true);
      expect(games.length, equals(30));
    });

    test('with is_released FALSE', () async {
      var games = await cw.getGames(isReleased: false);
      expect(games.length, equals(30));
    });

    test('with is_cracked TRUE', () async {
      var games = await cw.getGames(isCracked: true);
      expect(games.length, equals(30));
    });

    test('with is_cracked FALSE', () async {
      var games = await cw.getGames(isCracked: false);
      expect(games.length, equals(30));
    });
  });

  group('getCracks', () {
    CrackWatch cw;

    setUp(() async {
      cw = CrackWatch();
      await Future.delayed(const Duration(seconds: 2));
    });

    test('without page number', () async {
      var cracks = await cw.getCracks();
      expect(cracks.length, equals(30));
    });

    test('with page number', () async {
      var cracks = await cw.getCracks(page: 1);
      expect(cracks.length, equals(30));
    });
  });
}
